Frappy: Framework for programming secnodes in Python
====================================================

Frappy is a Python-framework for writing [SECoP](https://github.com/SampleEnvironment/SECoP) servers (called SECNodes or Nodes) and Clients.
It comes with its own Graphical client and a collection of example Nodes.
It is able to use TCP and Serial connections.

To get started, look at the provided demo, the provided examples, or have a look
at the INTRODUCTION section.

Main development is done
[here](https://forge.frm2.tum.de/review/q/project:secop%252Ffrappy)
and a readonly GitHub-mirror for easier access is available
[here](https://github.com/SampleEnvironment/frappy).

Requirements
------------

See `requirements.txt`.

Demo
----

Use the following command after installing the dependencies:

```
$ make demo
```

Documentation
-------------

[See here for documentation of Frappy](https://forge.frm2.tum.de/public/doc/frappy/html/)
